==> isbnlib-3.8.3.tar.gz: isbnlib-3.8.3/isbnlib/_data/data4info.py <==
# -*- coding: utf-8 -*-
# flake8: noqa
# GeneratedWith: mk_data4info.py (isbntools)
# MessageSource: http://www.isbn-international.org/agency?rmxml=1
# MessageDate: Thu, 25 Jan 2018 17:00:24 CET
# MessageSerialNumber: 6917d459-aa73-47df-bf9d-3f95448b863e
d = {
    '978-607': 'Mexico',
    '978-99947': 'Tajikistan',
    '978-960': 'Greece',
    '978-0': 'English language',
    '978-9975': 'Moldova',
    '978-99905': 'Bolivia',
    '978-99939': 'Guatemala',
    '978-9935': 'Iceland',
    '978-972': 'Portugal',
    '978-9973': 'Tunisia',
    '978-9948': 'United Arab Emirates',
    '978-99915': 'Maldives',
    '978-99935': 'Haiti',
    '978-99964': 'Nicaragua',
    '978-99919': 'Benin',
    '978-9942': 'Ecuador',
    '978-99966': 'Kuwait',
    '978-99903': 'Mauritius',
    '978-99912': 'Botswana',
    '978-953': 'Croatia',
    '978-966': 'Ukraine',
    '978-99934': 'Dominican Republic',
    '978-9949': 'Estonia',
    '978-9930': 'Costa Rica',
    '978-952': 'Finland',
    '978-99926': 'Honduras',
    '978-99961': 'El Salvador',
    '978-9961': 'Algeria',
    '978-9927': 'Qatar',
    '978-962': 'Hong Kong, China',
    '978-9928': 'Albania',
    '978-603': 'Saudi Arabia',
    '978-619': 'Bulgaria',
    '978-9970': 'Uganda',
    '978-9967': 'Kyrgyz Republic',
    '978-99962': 'Mongolia',
    '978-99958': 'Bahrain',
    '978-9974': 'Uruguay',
    '978-99908': 'Malawi',
    '978-99954': 'Bolivia',
    '978-80': 'former Czechoslovakia',
    '978-9968': 'Costa Rica',
    '978-622': 'Iran',
    '978-9945': 'Dominican Republic',
    '978-9956': 'Cameroon',
    '978-9979': 'Iceland',
    '978-91': 'Sweden',
    '978-969': 'Pakistan',
    '978-968': 'Mexico',
    '978-963': 'Hungary',
    '978-980': 'Venezuela',
    '978-99977': 'Rwanda',
    '978-982': 'South Pacific',
    '978-99952': 'Mali',
    '978-973': 'Romania',
    '978-985': 'Belarus',
    '978-9946': 'Korea, P.D.R.',
    '978-99916': 'Namibia',
    '978-621': 'Philippines',
    '978-84': 'Spain',
    '978-971': 'Philippines',
    '978-99932': 'Malta',
    '978-609': 'Lithuania',
    '978-616': 'Thailand',
    '978-604': 'Vietnam',
    '978-9965': 'Kazakhstan',
    '978-600': 'Iran',
    '978-5': 'former U.S.S.R',
    '978-961': 'Slovenia',
    '978-99946': 'Nepal',
    '978-9972': 'Peru',
    '978-99918': 'Faroe Islands',
    '978-99967': 'Paraguay',
    '978-967': 'Malaysia',
    '978-9938': 'Tunisia',
    '978-986': 'Taiwan',
    '978-9926': 'Bosnia and Herzegovina',
    '978-9920': 'Morocco',
    '978-989': 'Portugal',
    '978-606': 'Romania',
    '978-99956': 'Albania',
    '978-88': 'Italy',
    '978-99917': 'Brunei Darussalam',
    '978-99902': 'Reserved Agency',
    '978-99910': 'Sierra Leone',
    '978-9989': 'Macedonia',
    '978-81': 'India',
    '978-99931': 'Seychelles',
    '978-9929': 'Guatemala',
    '978-958': 'Colombia',
    '978-99930': 'Armenia',
    '978-99968': 'Botswana',
    '978-99921': 'Qatar',
    '978-984': 'Bangladesh',
    '978-975': 'Turkey',
    '978-99909': 'Malta',
    '978-955': 'Sri Lanka',
    '978-9933': 'Syria',
    '978-9984': 'Latvia',
    '978-9925': 'Cyprus',
    '978-612': 'Peru',
    '978-976': 'Caribbean Community',
    '978-99906': 'Kuwait',
    '978-9958': 'Bosnia and Herzegovina',
    '978-965': 'Israel',
    '978-9941': 'Georgia',
    '978-977': 'Egypt',
    '978-99948': 'Eritrea',
    '978-9966': 'Kenya',
    '978-9924': 'Cambodia',
    '978-987': 'Argentina',
    '978-99937': 'Macau',
    '978-9985': 'Estonia',
    '978-608': 'Macedonia',
    '978-9988': 'Ghana',
    '978-9964': 'Ghana',
    '978-9971': 'Singapore',
    '978-9953': 'Lebanon',
    '978-9963': 'Cyprus',
    '978-99976': 'Srpska, Republic of',
    '978-9986': 'Lithuania',
    '978-99969': 'Oman',
    '978-99955': 'Srpska, Republic of',
    '978-988': 'Hong Kong, China',
    '978-9978': 'Ecuador',
    '978-9957': 'Jordan',
    '978-99970': 'Haiti',
    '978-9955': 'Lithuania',
    '978-89': 'Korea, Republic',
    '978-99978': 'Mongolia',
    '978-7': "China, People's Republic",
    '978-99953': 'Paraguay',
    '978-82': 'Norway',
    '978-9981': 'Morocco',
    '978-983': 'Malaysia',
    '978-9923': 'Jordan',
    '978-613': 'Mauritius',
    '978-9932': "Lao People's Democratic Republic",
    '978-99957': 'Malta',
    '978-956': 'Chile',
    '978-90': 'Netherlands',
    '978-615': 'Hungary',
    '978-9976': 'Tanzania',
    '978-99949': 'Mauritius',
    '978-4': 'Japan',
    '978-99943': 'Albania',
    '978-99942': 'Sudan',
    '978-9951': 'Kosova',
    '978-99951': 'Reserved Agency',
    '978-9983': 'Gambia',
    '978-951': 'Finland',
    '978-2': 'French language',
    '978-99959': 'Luxembourg',
    '978-93': 'India',
    '978-981': 'Singapore',
    '978-9943': 'Uzbekistan',
    '978-99927': 'Albania',
    '978-602': 'Indonesia',
    '978-950': 'Argentina',
    '978-99979': 'Honduras',
    '978-611': 'Thailand',
    '978-9939': 'Armenia',
    '979-12': 'Italy',
    '978-99973': 'Mongolia',
    '978-99924': 'Nicaragua',
    '978-601': 'Kazakhstan',
    '978-99929': 'Mongolia',
    '978-614': 'Lebanon',
    '978-9922': 'Iraq',
    '978-85': 'Brazil',
    '978-959': 'Cuba',
    '978-9962': 'Panama',
    '978-99975': 'Tajikistan',
    '978-99960': 'Malawi',
    '978-9952': 'Azerbaijan',
    '978-9934': 'Latvia',
    '979-10': 'France',
    '978-974': 'Thailand',
    '978-9950': 'Palestine',
    '978-99920': 'Andorra',
    '978-99940': 'Georgia',
    '978-1': 'English language',
    '978-9960': 'Saudi Arabia',
    '978-9954': 'Morocco',
    '978-9987': 'Tanzania',
    '978-99963': 'Cambodia',
    '978-9947': 'Algeria',
    '978-99950': 'Cambodia',
    '978-83': 'Poland',
    '978-99925': 'Paraguay',
    '978-99936': 'Bhutan',
    '978-9936': 'Afghanistan',
    '978-9977': 'Costa Rica',
    '979-11': 'Korea, Republic',
    '978-9940': 'Montenegro',
    '978-99901': 'Bahrain',
    '978-99945': 'Namibia',
    '978-9959': 'Libya',
    '978-99971': 'Myanmar',
    '978-964': 'Iran',
    '978-99980': 'Bhutan',
    '978-92': 'International NGO Publishers and EU Organizations',
    '978-99913': 'Andorra',
    '978-99928': 'Georgia',
    '978-99922': 'Guatemala',
    '978-99933': 'Nepal',
    '978-978': 'Nigeria',
    '978-9980': 'Papua New Guinea',
    '978-99923': 'El Salvador',
    '978-99941': 'Armenia',
    '978-618': 'Greece',
    '978-9937': 'Nepal',
    '978-620': 'Mauritius',
    '978-970': 'Mexico',
    '978-9944': 'Turkey',
    '978-99972': 'Faroe Islands',
    '978-99914': 'International NGO Publishers',
    '978-99965': 'Macau',
    '978-3': 'German language',
    '978-9982': 'Zambia',
    '978-979': 'Indonesia',
    '978-99974': 'Bolivia',
    '978-9931': 'Algeria',
    '978-86': 'former Yugoslavia',
    '978-94': 'Netherlands',
    '978-87': 'Denmark',
    '978-99904': 'Curaçao',
    '978-99944': 'Ethiopia',
    '978-617': 'Ukraine',
    '978-957': 'Taiwan',
    '978-605': 'Turkey',
    '978-99938': 'Srpska, Republic of',
    '978-954': 'Bulgaria',
    '978-9921': 'Kuwait',
    '978-99911': 'Lesotho'
}
identifiers = (('978-0', '978-1', '978-2', '978-3', '978-4', '978-5', '978-7'),
               ('978-80', '978-81', '978-82', '978-83', '978-84', '978-85',
                '978-86', '978-87', '978-88', '978-89', '978-90', '978-91',
                '978-92', '978-93', '978-94', '979-10', '979-11', '979-12'),
               ('978-600', '978-601', '978-602', '978-603', '978-604',
                '978-605', '978-606', '978-607', '978-608', '978-609',
                '978-611', '978-612', '978-613', '978-614', '978-615',
                '978-616', '978-617', '978-618', '978-619', '978-620',
                '978-621', '978-622', '978-950', '978-951', '978-952',
                '978-953', '978-954', '978-955', '978-956', '978-957',
                '978-958', '978-959', '978-960', '978-961', '978-962',
                '978-963', '978-964', '978-965', '978-966', '978-967',
                '978-968', '978-969', '978-970', '978-971', '978-972',
                '978-973', '978-974', '978-975', '978-976', '978-977',
                '978-978', '978-979', '978-980', '978-981', '978-982',
                '978-983', '978-984', '978-985', '978-986', '978-987',
                '978-988', '978-989'),
               ('978-9920', '978-9921', '978-9922', '978-9923', '978-9924',
                '978-9925', '978-9926', '978-9927', '978-9928', '978-9929',
                '978-9930', '978-9931', '978-9932', '978-9933', '978-9934',
                '978-9935', '978-9936', '978-9937', '978-9938', '978-9939',
                '978-9940', '978-9941', '978-9942', '978-9943', '978-9944',
                '978-9945', '978-9946', '978-9947', '978-9948', '978-9949',
                '978-9950', '978-9951', '978-9952', '978-9953', '978-9954',
                '978-9955', '978-9956', '978-9957', '978-9958', '978-9959',
                '978-9960', '978-9961', '978-9962', '978-9963', '978-9964',
                '978-9965', '978-9966', '978-9967', '978-9968', '978-9970',
                '978-9971', '978-9972', '978-9973', '978-9974', '978-9975',
                '978-9976', '978-9977', '978-9978', '978-9979', '978-9980',
                '978-9981', '978-9982', '978-9983', '978-9984', '978-9985',
                '978-9986', '978-9987', '978-9988', '978-9989'),
               ('978-99901', '978-99902', '978-99903', '978-99904',
                '978-99905', '978-99906', '978-99908', '978-99909',
                '978-99910', '978-99911', '978-99912', '978-99913',
                '978-99914', '978-99915', '978-99916', '978-99917',
                '978-99918', '978-99919', '978-99920', '978-99921',
                '978-99922', '978-99923', '978-99924', '978-99925',
                '978-99926', '978-99927', '978-99928', '978-99929',
                '978-99930', '978-99931', '978-99932', '978-99933',
                '978-99934', '978-99935', '978-99936', '978-99937',
                '978-99938', '978-99939', '978-99940', '978-99941',
                '978-99942', '978-99943', '978-99944', '978-99945',
                '978-99946', '978-99947', '978-99948', '978-99949',
                '978-99950', '978-99951', '978-99952', '978-99953',
                '978-99954', '978-99955', '978-99956', '978-99957',
                '978-99958', '978-99959', '978-99960', '978-99961',
                '978-99962', '978-99963', '978-99964', '978-99965',
                '978-99966', '978-99967', '978-99968', '978-99969',
                '978-99970', '978-99971', '978-99972', '978-99973',
                '978-99974', '978-99975', '978-99976', '978-99977',
                '978-99978', '978-99979', '978-99980'))
RDDATE = '20180125'

==> isbnlib-3.8.4.tar.gz: isbnlib-3.8.4/isbnlib/_data/data4info.py <==
# -*- coding: utf-8 -*-
# flake8: noqa
d = {
    '978-9989': 'Macedonia',
    '978-99957': 'Malta',
    '978-99954': 'Bolivia',
    '978-99936': 'Bhutan',
    '978-9972': 'Peru',
    '978-99935': 'Haiti',
    '978-9938': 'Tunisia',
    '978-952': 'Finland',
    '978-971': 'Philippines',
    '978-9955': 'Lithuania',
    '978-99980': 'Bhutan',
    '978-604': 'Vietnam',
    '978-9930': 'Costa Rica',
    '978-92': 'International NGO Publishers and EU Organizations',
    '978-99944': 'Ethiopia',
    '978-9926': 'Bosnia and Herzegovina',
    '978-7': "China, People's Republic",
    '978-9936': 'Afghanistan',
    '978-614': 'Lebanon',
    '978-4': 'Japan',
    '978-99976': 'Srpska, Republic of',
    '978-9986': 'Lithuania',
    '978-9943': 'Uzbekistan',
    '978-99949': 'Mauritius',
    '979-11': 'Korea, Republic',
    '978-99904': 'Curaçao',
    '978-616': 'Thailand',
    '978-81': 'India',
    '978-99940': 'Georgia',
    '978-984': 'Bangladesh',
    '978-608': 'Macedonia',
    '978-99943': 'Albania',
    '978-99934': 'Dominican Republic',
    '978-88': 'Italy',
    '978-99925': 'Paraguay',
    '978-618': 'Greece',
    '978-959': 'Cuba',
    '978-99964': 'Nicaragua',
    '978-613': 'Mauritius',
    '978-9980': 'Papua New Guinea',
    '978-977': 'Egypt',
    '978-89': 'Korea, Republic',
    '978-99938': 'Srpska, Republic of',
    '978-957': 'Taiwan',
    '978-601': 'Kazakhstan',
    '978-603': 'Saudi Arabia',
    '978-976': 'Caribbean Community',
    '978-9961': 'Algeria',
    '978-9966': 'Kenya',
    '978-9946': 'Korea, P.D.R.',
    '978-987': 'Argentina',
    '978-970': 'Mexico',
    '978-981': 'Singapore',
    '978-99978': 'Mongolia',
    '978-99977': 'Rwanda',
    '978-99931': 'Seychelles',
    '978-80': 'former Czechoslovakia',
    '978-99971': 'Myanmar',
    '979-10': 'France',
    '978-99910': 'Sierra Leone',
    '978-962': 'Hong Kong, China',
    '978-99979': 'Honduras',
    '978-975': 'Turkey',
    '978-99939': 'Guatemala',
    '978-99948': 'Eritrea',
    '978-99974': 'Bolivia',
    '978-99950': 'Cambodia',
    '978-956': 'Chile',
    '978-85': 'Brazil',
    '978-600': 'Iran',
    '978-99968': 'Botswana',
    '979-12': 'Italy',
    '978-606': 'Romania',
    '978-980': 'Venezuela',
    '978-99953': 'Paraguay',
    '978-9982': 'Zambia',
    '978-99946': 'Nepal',
    '978-619': 'Bulgaria',
    '978-99911': 'Lesotho',
    '978-99913': 'Andorra',
    '978-9920': 'Morocco',
    '978-99933': 'Nepal',
    '978-9979': 'Iceland',
    '978-961': 'Slovenia',
    '978-0': 'English language',
    '978-982': 'South Pacific',
    '978-99914': 'International NGO Publishers',
    '978-99967': 'Paraguay',
    '978-83': 'Poland',
    '978-9927': 'Qatar',
    '978-9947': 'Algeria',
    '978-989': 'Portugal',
    '978-9983': 'Gambia',
    '978-9967': 'Kyrgyz Republic',
    '978-9937': 'Nepal',
    '978-985': 'Belarus',
    '978-99919': 'Benin',
    '978-99981': 'Macau',
    '978-99972': 'Faroe Islands',
    '978-967': 'Malaysia',
    '978-9950': 'Palestine',
    '978-9988': 'Ghana',
    '978-621': 'Philippines',
    '978-9953': 'Lebanon',
    '978-99909': 'Malta',
    '978-99923': 'El Salvador',
    '978-99918': 'Faroe Islands',
    '978-9965': 'Kazakhstan',
    '978-99912': 'Botswana',
    '978-99947': 'Tajikistan',
    '978-9981': 'Morocco',
    '978-978': 'Nigeria',
    '978-90': 'Netherlands',
    '978-9940': 'Montenegro',
    '978-99941': 'Armenia',
    '978-9949': 'Estonia',
    '978-9944': 'Turkey',
    '978-9951': 'Kosova',
    '978-9934': 'Latvia',
    '978-958': 'Colombia',
    '978-99958': 'Bahrain',
    '978-988': 'Hong Kong, China',
    '978-99906': 'Kuwait',
    '978-99917': 'Brunei Darussalam',
    '978-9960': 'Saudi Arabia',
    '978-9921': 'Kuwait',
    '978-973': 'Romania',
    '978-968': 'Mexico',
    '978-9956': 'Cameroon',
    '978-94': 'Netherlands',
    '978-9963': 'Cyprus',
    '978-9925': 'Cyprus',
    '978-951': 'Finland',
    '978-99969': 'Oman',
    '978-99905': 'Bolivia',
    '978-9924': 'Cambodia',
    '978-9933': 'Syria',
    '978-99908': 'Malawi',
    '978-84': 'Spain',
    '978-99903': 'Mauritius',
    '978-605': 'Turkey',
    '978-9987': 'Tanzania',
    '978-99922': 'Guatemala',
    '978-9968': 'Costa Rica',
    '978-9971': 'Singapore',
    '978-9923': 'Jordan',
    '978-93': 'India',
    '978-99945': 'Namibia',
    '978-9978': 'Ecuador',
    '978-960': 'Greece',
    '978-99902': 'Reserved Agency',
    '978-617': 'Ukraine',
    '978-99962': 'Mongolia',
    '978-99960': 'Malawi',
    '978-9928': 'Albania',
    '978-9976': 'Tanzania',
    '978-954': 'Bulgaria',
    '978-2': 'French language',
    '978-9973': 'Tunisia',
    '978-964': 'Iran',
    '978-615': 'Hungary',
    '978-965': 'Israel',
    '978-602': 'Indonesia',
    '978-9939': 'Armenia',
    '978-99951': 'Reserved Agency',
    '978-99965': 'Macau',
    '978-99959': 'Luxembourg',
    '978-9957': 'Jordan',
    '978-9977': 'Costa Rica',
    '978-611': 'Thailand',
    '978-99970': 'Haiti',
    '978-9954': 'Morocco',
    '978-99952': 'Mali',
    '978-9948': 'United Arab Emirates',
    '978-5': 'former U.S.S.R',
    '978-9970': 'Uganda',
    '978-9962': 'Panama',
    '978-972': 'Portugal',
    '978-9958': 'Bosnia and Herzegovina',
    '978-983': 'Malaysia',
    '978-974': 'Thailand',
    '978-9952': 'Azerbaijan',
    '978-87': 'Denmark',
    '978-99930': 'Armenia',
    '978-612': 'Peru',
    '978-99927': 'Albania',
    '978-9931': 'Algeria',
    '978-99937': 'Macau',
    '978-9929': 'Guatemala',
    '978-99928': 'Georgia',
    '978-986': 'Taiwan',
    '978-9975': 'Moldova',
    '978-99975': 'Tajikistan',
    '978-99955': 'Srpska, Republic of',
    '978-99961': 'El Salvador',
    '978-9985': 'Estonia',
    '978-99924': 'Nicaragua',
    '978-622': 'Iran',
    '978-91': 'Sweden',
    '978-9984': 'Latvia',
    '978-953': 'Croatia',
    '978-99920': 'Andorra',
    '978-99932': 'Malta',
    '978-9964': 'Ghana',
    '978-979': 'Indonesia',
    '978-9932': "Lao People's Democratic Republic",
    '978-9941': 'Georgia',
    '978-99926': 'Honduras',
    '978-955': 'Sri Lanka',
    '978-966': 'Ukraine',
    '978-9935': 'Iceland',
    '978-607': 'Mexico',
    '978-99921': 'Qatar',
    '978-9959': 'Libya',
    '978-99963': 'Cambodia',
    '978-9942': 'Ecuador',
    '978-620': 'Mauritius',
    '978-99915': 'Maldives',
    '978-609': 'Lithuania',
    '978-9974': 'Uruguay',
    '978-99966': 'Kuwait',
    '978-99956': 'Albania',
    '978-99973': 'Mongolia',
    '978-9922': 'Iraq',
    '978-963': 'Hungary',
    '978-99916': 'Namibia',
    '978-1': 'English language',
    '978-99929': 'Mongolia',
    '978-3': 'German language',
    '978-950': 'Argentina',
    '978-82': 'Norway',
    '978-969': 'Pakistan',
    '978-99901': 'Bahrain',
    '978-9945': 'Dominican Republic',
    '978-86': 'former Yugoslavia',
    '978-99942': 'Sudan'
}
identifiers = (('978-0', '978-1', '978-2', '978-3', '978-4', '978-5', '978-7'),
               ('978-80', '978-81', '978-82', '978-83', '978-84', '978-85',
                '978-86', '978-87', '978-88', '978-89', '978-90', '978-91',
                '978-92', '978-93', '978-94', '979-10', '979-11', '979-12'),
               ('978-600', '978-601', '978-602', '978-603', '978-604',
                '978-605', '978-606', '978-607', '978-608', '978-609',
                '978-611', '978-612', '978-613', '978-614', '978-615',
                '978-616', '978-617', '978-618', '978-619', '978-620',
                '978-621', '978-622', '978-950', '978-951', '978-952',
                '978-953', '978-954', '978-955', '978-956', '978-957',
                '978-958', '978-959', '978-960', '978-961', '978-962',
                '978-963', '978-964', '978-965', '978-966', '978-967',
                '978-968', '978-969', '978-970', '978-971', '978-972',
                '978-973', '978-974', '978-975', '978-976', '978-977',
                '978-978', '978-979', '978-980', '978-981', '978-982',
                '978-983', '978-984', '978-985', '978-986', '978-987',
                '978-988', '978-989'),
               ('978-9920', '978-9921', '978-9922', '978-9923', '978-9924',
                '978-9925', '978-9926', '978-9927', '978-9928', '978-9929',
                '978-9930', '978-9931', '978-9932', '978-9933', '978-9934',
                '978-9935', '978-9936', '978-9937', '978-9938', '978-9939',
                '978-9940', '978-9941', '978-9942', '978-9943', '978-9944',
                '978-9945', '978-9946', '978-9947', '978-9948', '978-9949',
                '978-9950', '978-9951', '978-9952', '978-9953', '978-9954',
                '978-9955', '978-9956', '978-9957', '978-9958', '978-9959',
                '978-9960', '978-9961', '978-9962', '978-9963', '978-9964',
                '978-9965', '978-9966', '978-9967', '978-9968', '978-9970',
                '978-9971', '978-9972', '978-9973', '978-9974', '978-9975',
                '978-9976', '978-9977', '978-9978', '978-9979', '978-9980',
                '978-9981', '978-9982', '978-9983', '978-9984', '978-9985',
                '978-9986', '978-9987', '978-9988', '978-9989'),
               ('978-99901', '978-99902', '978-99903', '978-99904',
                '978-99905', '978-99906', '978-99908', '978-99909',
                '978-99910', '978-99911', '978-99912', '978-99913',
                '978-99914', '978-99915', '978-99916', '978-99917',
                '978-99918', '978-99919', '978-99920', '978-99921',
                '978-99922', '978-99923', '978-99924', '978-99925',
                '978-99926', '978-99927', '978-99928', '978-99929',
                '978-99930', '978-99931', '978-99932', '978-99933',
                '978-99934', '978-99935', '978-99936', '978-99937',
                '978-99938', '978-99939', '978-99940', '978-99941',
                '978-99942', '978-99943', '978-99944', '978-99945',
                '978-99946', '978-99947', '978-99948', '978-99949',
                '978-99950', '978-99951', '978-99952', '978-99953',
                '978-99954', '978-99955', '978-99956', '978-99957',
                '978-99958', '978-99959', '978-99960', '978-99961',
                '978-99962', '978-99963', '978-99964', '978-99965',
                '978-99966', '978-99967', '978-99968', '978-99969',
                '978-99970', '978-99971', '978-99972', '978-99973',
                '978-99974', '978-99975', '978-99976', '978-99977',
                '978-99978', '978-99979', '978-99980', '978-99981'))
RDDATE = '20180301'
